@@ -460,14 +460,13 @@ class Command(BaseCommand):
             "https://ajax.googleapis.com/ajax/libs/jquery/3.1.1/jquery.min.js")
         jq.tail = '\n'
 
+        workAroundComment = etree.Comment(
+            "Workaround for fixing Django CMS issues")
+
         addJ = etree.Element('script')
         addJ.set('src', 'js/FixTemplate.js')
         addJ.tail = '\n'
 
-        addWorkaround = etree.Element('script')
-        addWorkaround.set('src', 'js/Workaround.js')
-        addWorkaround.tail = '\n'
-
         metaDescription = etree.Element('meta')
         metaDescription.set("name", "description")
         metaDescription.set(
@@ -487,8 +486,8 @@ class Command(BaseCommand):
         if createMetaDescription:
             head.insert(0, metaDescription)
         head.insert(0, comment) 
-        head.insert(0, addWorkaround)
         head.insert(0, addJ)
+        head.insert(0, workAroundComment)
         head.insert(0, jq)
         head.insert(0, cmsData)  
         head.insert(0, pgAttr)
@@ -500,7 +499,7 @@ class Command(BaseCommand):
         head.text = '\n' + CMS_HEAD_FRONT_TAG + head.text
 
         cmsDiv = etree.Element('div')
-        cmsDiv.set("class", "cmsCollection")
+        cmsDiv.set("class", "_cmsCollection")
         cmsDiv.tail = '\n'
 
         body.append(cmsDiv)
