@@ -27,9 +27,7 @@ from django.core.management.base import BaseCommand
 from Iuppiter.Util import run
 from Zephyrus.boilerplate.management.commands import (
     PROJECT_MASHINES_DIR, PROJECT_MASHINES_ZIP, ROOT_DIR_PATH)
-from Zephyrus.boilerplate.management.commands import createLogger
-
-logger = createLogger(__name__, "BuildProducts.log")    
+from Zephyrus.boilerplate.management.commands import createLogger  
 
 class Command(BaseCommand):
 
@@ -38,10 +36,16 @@ class Command(BaseCommand):
     def add_arguments(self, parser):
         parser.add_argument('start', type=str, help="start folder")
         parser.add_argument('output', type=str, help="output folder")
+        parser.add_argument(
+            '-l', '--log', 
+            type=str, default="BuildProducts.log",
+            help="log file name.")
 
     def handle(self, *args, **options):
         startPath = options['start']
         dstPath = options['output']
+
+        logger = createLogger(__name__, options['log'])
         
         # create project
         machineName = hashlib.md5(
