@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: create_zip.py 10600 2017-12-04 04:16:19Z Lavender $
+# $Id: create_zip.py 10607 2017-12-05 09:15:47Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-12-04 12:16:19 +0800 (週一, 04 十二月 2017) $
-# $Revision: 10600 $
+# $Date: 2017-12-05 17:15:47 +0800 (週二, 05 十二月 2017) $
+# $Revision: 10607 $
 
 import os
 import shutil
@@ -31,6 +31,7 @@ from Zephyrus.boilerplate.management.commands import (
     IMAGES_DIR_PATH, ROOT_DIR_PATH, FIXTURES_DIR_PATH)
 from Zephyrus.boilerplate.management.commands import createLogger
 from Zephyrus import ZEPHYRUS_VERSION
+from Iuppiter.Encoding import utf8
 
 logger = createLogger(__name__, "CreateZip.log")
 
@@ -64,13 +65,14 @@ class Command(BaseCommand):
                     for temp in files:
                         with open(os.path.join(root, temp)) as f:
                             htmlContent = f.read()
-                        print upc
-                        print complexity
+                        include = (("include '_tracking.html' with"
+                                    " upc='%s' complexity='%d'") % (
+                                        str(upc), complexity))
                         htmlContent = htmlContent.replace(
                             "<!--### include _tracking.html ###-->",
-                            ("{% " + "include '_tracking.html' with upc='%s' complexity='%d'" % (upc, complexity) + " %}")) 
+                            "{% " + include + " %}") 
                         with open(os.path.join(root, temp), 'wb') as f:
-                            f.write(htmlContent.encode('utf8'))
+                            f.write(utf8(htmlContent))
                         content += htmlContent
                 data['checksum'] = hashlib.md5(content).hexdigest()
 
@@ -82,7 +84,7 @@ class Command(BaseCommand):
                 content = temp.render()
                 with open(os.path.join(
                     TEMPLATES_DIR_PATH, '_tracking.html'), 'wb') as f:
-                    f.write(content.encode('utf8'))
+                    f.write(utf8(content))
                 with open(os.path.join(
                     ROOT_DIR_PATH, 'MANIFAST.INFO'), 'wb') as f:
                     manifast = json.dumps({
@@ -91,19 +93,13 @@ class Command(BaseCommand):
                         'createTime': str(datetime.datetime.now()),
                         'ZephyrusVersion': ZEPHYRUS_VERSION,
                     })
-                    f.write(manifast.encode('utf8'))
+                    f.write(utf8(manifast))
                     
             templateName = options['templateName']
 
             zip = zipfile.ZipFile(
                 os.path.join(ROOT_DIR_PATH, '%s.zip' % templateName), mode='w')
 
-            temp = get_template('boilerplate/js/Workaround.js')
-            content = temp.render()
-            with open(os.path.join(
-                STATIC_DIR_PATH, 'js', 'Workaround.js'), 'wb') as f:
-                f.write(content.encode('utf8'))
-
             logger.info("-----Start copy templates-----")
             for root, dirs, files in os.walk(TEMPLATES_DIR_PATH):
                 for f in files:
@@ -130,12 +126,12 @@ class Command(BaseCommand):
             temp = get_template('boilerplate/py/setup.py')
             content = temp.render()
             with open(os.path.join(ROOT_DIR_PATH, 'setup.py'), 'wb') as f:
-                f.write(content.encode('utf8'))
+                f.write(utf8(content))
                 
             temp = get_template('boilerplate/txt/README.txt')
             content = temp.render()
             with open(os.path.join(ROOT_DIR_PATH, 'README.txt'), 'w') as f:
-                f.write(content.encode('utf8'))
+                f.write(utf8(content))
 
             zip.write('./README.txt')
             logger.info("Zip README.txt")
