@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: pluginize.py 10554 2017-11-26 13:21:13Z Lavender $
+# $Id: pluginize.py 10591 2017-12-03 05:37:16Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-11-26 21:21:13 +0800 (週日, 26 十一月 2017) $
-# $Revision: 10554 $
+# $Date: 2017-12-03 13:37:16 +0800 (週日, 03 十二月 2017) $
+# $Revision: 10591 $
 
 import os
 import json
@@ -209,118 +209,121 @@ class Command(BaseCommand):
     requires_model_validation = False
     
     def handle(self, language='', *args, **options):
-        
-        from django import template
-        from django.core.urlresolvers import reverse
-        from django.contrib.auth.models import AnonymousUser
-        
-        from sekizai.context import SekizaiContext
-        
-        from cms.templatetags.cms_tags import register
-        
-        if language:
-            Placeholder2.lang = language
-        else:
-            if hasattr(settings, 'LANGUAGE_CODE'):
-                Placeholder2.lang = settings.LANGUAGE_CODE
-        
-        register.tags['placeholder'] = Placeholder2
-        #register.tag(Placeholder2)
-        
-        path = TEMPLATES_DIR_PATH
-        logger.info('Processing...')
-
-        if not os.path.exists(os.path.join(STATIC_DIR_PATH, 'js')):
-            os.mkdir(os.path.join(STATIC_DIR_PATH, 'js'))
+        try:
+            from django import template
+            from django.core.urlresolvers import reverse
+            from django.contrib.auth.models import AnonymousUser
             
-        if not os.path.exists(FIXTURES_DIR_PATH):
-            os.mkdir(FIXTURES_DIR_PATH)
-            with open(
-                os.path.join(FIXTURES_DIR_PATH, '__init__.py'), 'w') as f:
-                pass
+            from sekizai.context import SekizaiContext
             
-        if os.path.isfile(os.path.join(ROOT_DIR_PATH, 'info.json')):
-            with open(os.path.join(ROOT_DIR_PATH, 'info.json')) as jsonfile:
-                data = json.load(jsonfile)
-
-            data['pages'] = len(os.listdir(path))
-
-            with open(os.path.join(ROOT_DIR_PATH, 'info.json'), 'w') as f:
-                line = json.dumps(data)
-                f.write(line)
-
-        """
-        with open(jsPath, 'w') as f:
-            f.write("$j( document ).ready(function() {\n")
-        """
-        @transaction.atomic
-        def process():
-            for file in os.listdir(path):
-                file = os.path.join(path, file)
-                
-                result = os.path.splitext(file)[-1]
-                if not result == ".html":
-                    continue
-                    
-                logger.info(file)
-                f = open(file)
-                t = template.Template(f.read())
-                c = SekizaiContext()
-                factory = RequestFactory()
-                c['request'] = factory.get('/' + Placeholder2.lang + '/')
-                c['request'].user = AnonymousUser()
-                c['request'].current_page = Page.objects.get(pk=1)
-                t.render(c)
-                f.close()
-
-        process()
-        """
-        divClass = 'div' + hashlib.md5(' __tmp__img__div').hexdigest()
-        with open(jsPath, 'a+') as f:
-            f.write("$j('.%s').remove();\n" % divClass)
-            f.write("});")
-        """
-        # Unique List obj
-        newTagList = []
-        for tag in tagList:
-            notAdd = False
-            for tag2 in newTagList:
-                if tag2 == tag:
-                    notAdd = True
-            if not notAdd:
-                newTagList.append(tag)
-        temp = get_template('boilerplate/js/FixTemplate.js')
-        replaceStr = Context({
-            'tagList': newTagList, 
-        })
-        
-        content = temp.render(replaceStr)
-        with open(jsPath, 'w') as f:
-            f.write(content)
-
-        if os.path.isfile(os.path.join(ROOT_DIR_PATH, 'info.json')):
-            with open(os.path.join(ROOT_DIR_PATH, 'info.json')) as jsonfile:
-                data = json.load(jsonfile)
-        
-            if 'complexity' in data:
-                logger.info('Complexity : %d' % data['complexity'])
+            from cms.templatetags.cms_tags import register
+            
+            if language:
+                Placeholder2.lang = language
             else:
-                logger.error('%s Complexity = 0' % data['slug'])
-                raise CommandError('%s Complexity = 0' % data['slug'])
-            if 'upc' in data:
-                logger.info('UPC : %s' % data['upc'])
+                if hasattr(settings, 'LANGUAGE_CODE'):
+                    Placeholder2.lang = settings.LANGUAGE_CODE
+            
+            register.tags['placeholder'] = Placeholder2
+            #register.tag(Placeholder2)
+            
+            path = TEMPLATES_DIR_PATH
+            logger.info('Processing...')
 
-            for file in os.listdir(path):
-                file = os.path.join(path, file)
-                with open(file) as f:
-                    content = f.read()
-                content = content.replace(
-                    "complexity=CMS_PLUGINIZE_REPLACE", 
-                    "complexity=%d" % data['complexity'])
-                with open(file, 'w') as f:
-                    f.write(content)
-        
-        logger.info('DONE!')
+            if not os.path.exists(os.path.join(STATIC_DIR_PATH, 'js')):
+                os.mkdir(os.path.join(STATIC_DIR_PATH, 'js'))
+                
+            if not os.path.exists(FIXTURES_DIR_PATH):
+                os.mkdir(FIXTURES_DIR_PATH)
+                with open(
+                    os.path.join(FIXTURES_DIR_PATH, '__init__.py'), 'w') as f:
+                    pass
+                
+            if os.path.isfile(os.path.join(ROOT_DIR_PATH, 'info.json')):
+                with open(os.path.join(ROOT_DIR_PATH, 'info.json')) as jsonfile:
+                    data = json.load(jsonfile)
+
+                data['pages'] = len(os.listdir(path))
+
+                with open(os.path.join(ROOT_DIR_PATH, 'info.json'), 'w') as f:
+                    line = json.dumps(data)
+                    f.write(line)
+
+            """
+            with open(jsPath, 'w') as f:
+                f.write("$j( document ).ready(function() {\n")
+            """
+            @transaction.atomic
+            def process():
+                for file in os.listdir(path):
+                    file = os.path.join(path, file)
+                    
+                    result = os.path.splitext(file)[-1]
+                    if not result == ".html":
+                        continue
+                        
+                    logger.info(file)
+                    f = open(file)
+                    t = template.Template(f.read())
+                    c = SekizaiContext()
+                    factory = RequestFactory()
+                    c['request'] = factory.get('/' + Placeholder2.lang + '/')
+                    c['request'].user = AnonymousUser()
+                    c['request'].current_page = Page.objects.get(pk=1)
+                    t.render(c)
+                    f.close()
+
+            process()
+            """
+            divClass = 'div' + hashlib.md5(' __tmp__img__div').hexdigest()
+            with open(jsPath, 'a+') as f:
+                f.write("$j('.%s').remove();\n" % divClass)
+                f.write("});")
+            """
+            # Unique List obj
+            newTagList = []
+            for tag in tagList:
+                notAdd = False
+                for tag2 in newTagList:
+                    if tag2 == tag:
+                        notAdd = True
+                if not notAdd:
+                    newTagList.append(tag)
+            temp = get_template('boilerplate/js/FixTemplate.js')
+            replaceStr = Context({
+                'tagList': newTagList, 
+            })
+            
+            content = temp.render(replaceStr)
+            with open(jsPath, 'w') as f:
+                f.write(content)
+
+            if os.path.isfile(os.path.join(ROOT_DIR_PATH, 'info.json')):
+                with open(os.path.join(ROOT_DIR_PATH, 'info.json')) as jsonfile:
+                    data = json.load(jsonfile)
+            
+                if 'complexity' in data:
+                    logger.info('Complexity : %d' % data['complexity'])
+                else:
+                    logger.error('%s Complexity = 0' % data['slug'])
+                    raise CommandError('%s Complexity = 0' % data['slug'])
+                if 'upc' in data:
+                    logger.info('UPC : %s' % data['upc'])
+
+                for file in os.listdir(path):
+                    file = os.path.join(path, file)
+                    with open(file) as f:
+                        content = f.read()
+                    content = content.replace(
+                        "complexity=CMS_PLUGINIZE_REPLACE", 
+                        "complexity=%d" % data['complexity'])
+                    with open(file, 'w') as f:
+                        f.write(content)
+            
+            logger.info('DONE!')
+        except Exception as e:
+            logger.error("pluginize error:%s" % e)
+            raise
         
 
         
