@@ -1,5 +1,8 @@
 var $j = jQuery.noConflict();
 
+// Fix img tag attributes lost after pluginize.
+// =============================================================================
+
 var findComments = function(el) {
     var arr = [];
     for(var i = 0; i < el.childNodes.length; i++) {
@@ -57,6 +60,7 @@ var addAttrs = function(target, attrs){
     };
 };
 
+
 $j(document).ready(function() {
     var commentNodes = findComments(document);
     
@@ -73,4 +77,43 @@ $j(document).ready(function() {
             addAttrs({{ tag.tag }}{{ tag.md5 }}, attrs{{ tag.md5 }})
         };
     {% endfor %}
-});
\ No newline at end of file
+});
+
+// =============================================================================
+
+// Fix Django CMS edit mode issues #2792.
+// =============================================================================
+
+$j(document).ready(function() {
+    var toAppendDiv = $j('div.cms-placeholder');  
+    $j('._cmsCollection').append(toAppendDiv);  
+    var toAppendScript = $j("script[id|='cms-plugin-child-classes']");  
+    $j('._cmsCollection').append(toAppendScript);
+    
+    $j("p[cmsboilerplatetag='p']").each(function(index) { 
+        var p = $j(this)
+        
+        var comment;
+        var next = this;
+        var tagList = [];
+        while(! comment){
+            next = next.nextSibling;
+            if(next.nodeValue == 'cmsboilerplatetag=p') {
+                comment = next;
+            } else {
+                tagList.push(next);
+            };
+        };
+        
+        for(var i = 0;i < tagList.length; i++) {
+            this.appendChild(tagList[i]);
+        };   
+        
+        var lastChild = p.children().last();
+        if($j.trim(lastChild.html()) == '' & lastChild.prop("tagName") == 'P') {
+            lastChild.remove();
+        };
+    });
+});
+
+// =============================================================================
\ No newline at end of file
